{
  "type": "record",
  "Aspect": {
    "name": "dataHubRemoteExecutorStatus"
  },
  "name": "RemoteExecutorStatus",
  "namespace": "com.linkedin.pegasus2avro.executor",
  "fields": [
    {
      "Searchable": {
        "fieldType": "KEYWORD"
      },
      "type": "string",
      "name": "executorPoolId",
      "doc": "References the 'id' defined in RemoteExecutorPoolKey"
    },
    {
      "type": "string",
      "name": "executorReleaseVersion",
      "doc": " Release Version (Tag) embedded into remote executor image"
    },
    {
      "type": "string",
      "name": "executorAddress",
      "doc": " IP address of the host where remote executor is running"
    },
    {
      "type": "string",
      "name": "executorHostname",
      "doc": "Hostname of the host where remote executor is running"
    },
    {
      "type": "float",
      "name": "executorUptime",
      "doc": "Uptime of the remote executor master process"
    },
    {
      "Searchable": {
        "fieldType": "BOOLEAN"
      },
      "type": "boolean",
      "name": "executorExpired",
      "default": false,
      "doc": "Flag indicating whether remote executor status record is stale.\nThis means executor no longer sends heartbeats and considered dead."
    },
    {
      "type": "boolean",
      "name": "executorStopped",
      "default": false,
      "doc": "Flag indicating whether remote executor is stopped, and properly reported its termination."
    },
    {
      "type": "boolean",
      "name": "executorEmbedded",
      "default": false,
      "doc": "Flag indicating whether remote executor is embedded into the coordinator pod"
    },
    {
      "type": "boolean",
      "name": "executorInternal",
      "default": false,
      "doc": "Flag indicating whether remote executor is Acryl managed executor"
    },
    {
      "type": "boolean",
      "name": "logDeliveryEnabled",
      "default": false,
      "doc": "Flag indicating whether log delivery is enabled by the customer in the given\nremote executor instance."
    },
    {
      "Searchable": {
        "fieldType": "COUNT",
        "queryByDefault": false
      },
      "type": "long",
      "name": "reportedAt",
      "doc": "UTC-based timestamp of the last reported status"
    }
  ]
}