{
  "type": "record",
  "Aspect": {
    "name": "dataProductKey",
    "keyForEntity": "dataProduct",
    "entityCategory": "core",
    "entityAspects": [
      "ownership",
      "glossaryTerms",
      "globalTags",
      "domains",
      "dataProductProperties",
      "institutionalMemory",
      "status",
      "structuredProperties",
      "forms",
      "testResults",
      "subTypes",
      "share",
      "origin"
    ]
  },
  "name": "DataProductKey",
  "namespace": "com.linkedin.pegasus2avro.dataproduct",
  "fields": [
    {
      "type": "string",
      "name": "id",
      "doc": "A unique id for the Data Product."
    }
  ],
  "doc": "Key for a Query"
}