# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
# isort: skip_file
from .....schema_classes import AdjustmentAlgorithmClass
from .....schema_classes import AssertionActionClass
from .....schema_classes import AssertionActionTypeClass
from .....schema_classes import AssertionActionsClass
from .....schema_classes import AssertionAdjustmentSettingsClass
from .....schema_classes import AssertionAnalyticsRunEventClass
from .....schema_classes import AssertionDryRunEventClass
from .....schema_classes import AssertionDryRunResultClass
from .....schema_classes import AssertionExclusionWindowClass
from .....schema_classes import AssertionExclusionWindowTypeClass
from .....schema_classes import AssertionInferenceDetailsClass
from .....schema_classes import AssertionInfoClass
from .....schema_classes import AssertionMetricClass
from .....schema_classes import AssertionMonitorSensitivityClass
from .....schema_classes import AssertionResultClass
from .....schema_classes import AssertionResultErrorClass
from .....schema_classes import AssertionResultErrorTypeClass
from .....schema_classes import AssertionResultTypeClass
from .....schema_classes import AssertionRunEventClass
from .....schema_classes import AssertionRunStatusClass
from .....schema_classes import AssertionSourceClass
from .....schema_classes import AssertionSourceTypeClass
from .....schema_classes import AssertionStdAggregationClass
from .....schema_classes import AssertionStdOperatorClass
from .....schema_classes import AssertionStdParameterClass
from .....schema_classes import AssertionStdParameterTypeClass
from .....schema_classes import AssertionStdParametersClass
from .....schema_classes import AssertionSummaryClass
from .....schema_classes import AssertionTypeClass
from .....schema_classes import AssertionValueChangeTypeClass
from .....schema_classes import BatchSpecClass
from .....schema_classes import CustomAssertionInfoClass
from .....schema_classes import DatasetAssertionInfoClass
from .....schema_classes import DatasetAssertionScopeClass
from .....schema_classes import FieldAssertionInfoClass
from .....schema_classes import FieldAssertionTypeClass
from .....schema_classes import FieldMetricAssertionClass
from .....schema_classes import FieldMetricTypeClass
from .....schema_classes import FieldTransformClass
from .....schema_classes import FieldTransformTypeClass
from .....schema_classes import FieldValuesAssertionClass
from .....schema_classes import FieldValuesFailThresholdClass
from .....schema_classes import FieldValuesFailThresholdTypeClass
from .....schema_classes import FixedIntervalScheduleClass
from .....schema_classes import FreshnessAssertionInfoClass
from .....schema_classes import FreshnessAssertionScheduleClass
from .....schema_classes import FreshnessAssertionScheduleTypeClass
from .....schema_classes import FreshnessAssertionTypeClass
from .....schema_classes import FreshnessCronScheduleClass
from .....schema_classes import FreshnessFieldKindClass
from .....schema_classes import FreshnessFieldSpecClass
from .....schema_classes import IncrementingSegmentFieldTransformerClass
from .....schema_classes import IncrementingSegmentFieldTransformerTypeClass
from .....schema_classes import IncrementingSegmentRowCountChangeClass
from .....schema_classes import IncrementingSegmentRowCountTotalClass
from .....schema_classes import IncrementingSegmentSpecClass
from .....schema_classes import RowCountChangeClass
from .....schema_classes import RowCountTotalClass
from .....schema_classes import SchemaAssertionCompatibilityClass
from .....schema_classes import SchemaAssertionInfoClass
from .....schema_classes import SqlAssertionInfoClass
from .....schema_classes import SqlAssertionTypeClass
from .....schema_classes import VolumeAssertionInfoClass
from .....schema_classes import VolumeAssertionTypeClass


AdjustmentAlgorithm = AdjustmentAlgorithmClass
AssertionAction = AssertionActionClass
AssertionActionType = AssertionActionTypeClass
AssertionActions = AssertionActionsClass
AssertionAdjustmentSettings = AssertionAdjustmentSettingsClass
AssertionAnalyticsRunEvent = AssertionAnalyticsRunEventClass
AssertionDryRunEvent = AssertionDryRunEventClass
AssertionDryRunResult = AssertionDryRunResultClass
AssertionExclusionWindow = AssertionExclusionWindowClass
AssertionExclusionWindowType = AssertionExclusionWindowTypeClass
AssertionInferenceDetails = AssertionInferenceDetailsClass
AssertionInfo = AssertionInfoClass
AssertionMetric = AssertionMetricClass
AssertionMonitorSensitivity = AssertionMonitorSensitivityClass
AssertionResult = AssertionResultClass
AssertionResultError = AssertionResultErrorClass
AssertionResultErrorType = AssertionResultErrorTypeClass
AssertionResultType = AssertionResultTypeClass
AssertionRunEvent = AssertionRunEventClass
AssertionRunStatus = AssertionRunStatusClass
AssertionSource = AssertionSourceClass
AssertionSourceType = AssertionSourceTypeClass
AssertionStdAggregation = AssertionStdAggregationClass
AssertionStdOperator = AssertionStdOperatorClass
AssertionStdParameter = AssertionStdParameterClass
AssertionStdParameterType = AssertionStdParameterTypeClass
AssertionStdParameters = AssertionStdParametersClass
AssertionSummary = AssertionSummaryClass
AssertionType = AssertionTypeClass
AssertionValueChangeType = AssertionValueChangeTypeClass
BatchSpec = BatchSpecClass
CustomAssertionInfo = CustomAssertionInfoClass
DatasetAssertionInfo = DatasetAssertionInfoClass
DatasetAssertionScope = DatasetAssertionScopeClass
FieldAssertionInfo = FieldAssertionInfoClass
FieldAssertionType = FieldAssertionTypeClass
FieldMetricAssertion = FieldMetricAssertionClass
FieldMetricType = FieldMetricTypeClass
FieldTransform = FieldTransformClass
FieldTransformType = FieldTransformTypeClass
FieldValuesAssertion = FieldValuesAssertionClass
FieldValuesFailThreshold = FieldValuesFailThresholdClass
FieldValuesFailThresholdType = FieldValuesFailThresholdTypeClass
FixedIntervalSchedule = FixedIntervalScheduleClass
FreshnessAssertionInfo = FreshnessAssertionInfoClass
FreshnessAssertionSchedule = FreshnessAssertionScheduleClass
FreshnessAssertionScheduleType = FreshnessAssertionScheduleTypeClass
FreshnessAssertionType = FreshnessAssertionTypeClass
FreshnessCronSchedule = FreshnessCronScheduleClass
FreshnessFieldKind = FreshnessFieldKindClass
FreshnessFieldSpec = FreshnessFieldSpecClass
IncrementingSegmentFieldTransformer = IncrementingSegmentFieldTransformerClass
IncrementingSegmentFieldTransformerType = IncrementingSegmentFieldTransformerTypeClass
IncrementingSegmentRowCountChange = IncrementingSegmentRowCountChangeClass
IncrementingSegmentRowCountTotal = IncrementingSegmentRowCountTotalClass
IncrementingSegmentSpec = IncrementingSegmentSpecClass
RowCountChange = RowCountChangeClass
RowCountTotal = RowCountTotalClass
SchemaAssertionCompatibility = SchemaAssertionCompatibilityClass
SchemaAssertionInfo = SchemaAssertionInfoClass
SqlAssertionInfo = SqlAssertionInfoClass
SqlAssertionType = SqlAssertionTypeClass
VolumeAssertionInfo = VolumeAssertionInfoClass
VolumeAssertionType = VolumeAssertionTypeClass

# fmt: on
