{
  "type": "record",
  "Aspect": {
    "name": "assertionSummary"
  },
  "name": "AssertionSummary",
  "namespace": "com.linkedin.pegasus2avro.assertion",
  "fields": [
    {
      "Searchable": {
        "fieldName": "lastFailedAtMillis",
        "fieldType": "DATETIME"
      },
      "type": [
        "null",
        "long"
      ],
      "name": "lastFailedAtMillis",
      "default": null,
      "doc": "The last failure event timestamp field as epoch at UTC in milliseconds."
    },
    {
      "Searchable": {
        "fieldName": "lastErroredAtMillis",
        "fieldType": "DATETIME"
      },
      "type": [
        "null",
        "long"
      ],
      "name": "lastErroredAtMillis",
      "default": null,
      "doc": "The last error event timestamp field as epoch at UTC in milliseconds."
    },
    {
      "Searchable": {
        "fieldName": "lastPassedAtMillis",
        "fieldType": "DATETIME"
      },
      "type": [
        "null",
        "long"
      ],
      "name": "lastPassedAtMillis",
      "default": null,
      "doc": "The last pass event timestamp field as epoch at UTC in milliseconds."
    }
  ],
  "doc": "Derived.\nTracks the latest summary details of an assertion."
}